@@ -21,6 +21,7 @@
 #include "local_filesys.h"
 #include "filelist_statusbar.h"
 #include "sizeformatting.h"
+#include "timeformatting.h"
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -279,8 +280,6 @@ CLocalListView::CLocalListView(wxWindow* pParent, CState *pState, CQueueView *pQ
 
 	SetDropTarget(new CLocalListViewDropTarget(this));
 
-	InitDateFormat();
-
 	EnablePrefixSearch(true);
 }
 
@@ -582,7 +581,7 @@ void CLocalListView::OnItemActivated(wxListEvent &event)
 
 	const bool queue_only = action == 1;
 
-	m_pQueue->QueueFile(queue_only, false, CLocalPath(m_dir), data->name, data->name, path, *pServer, data->size);
+	m_pQueue->QueueFile(queue_only, false, data->name, wxEmptyString, CLocalPath(m_dir), path, *pServer, data->size);
 	m_pQueue->QueueFile_Finish(true);
 }
 
@@ -1170,7 +1169,7 @@ void CLocalListView::OnMenuUpload(wxCommandEvent& event)
 		}
 		else
 		{
-			m_pQueue->QueueFile(queue_only, false, CLocalPath(m_dir), data->name, data->name, path, *pServer, data->size);
+			m_pQueue->QueueFile(queue_only, false, data->name, wxEmptyString, CLocalPath(m_dir), path, *pServer, data->size);
 			added = true;
 		}
 	}
@@ -1635,7 +1634,7 @@ void CLocalListView::OnBeginDrag(wxListEvent& event)
 		return;
 	}
 
-	CLabelEditBlocker(*this);
+	CLabelEditBlocker b(*this);
 
 	wxDropSource source(this);
 	source.SetData(obj);
@@ -1799,28 +1798,6 @@ void CLocalListView::RefreshFile(const wxString& file)
 	}
 }
 
-void CLocalListView::InitDateFormat()
-{
-	const wxString& dateFormat = COptions::Get()->GetOption(OPTION_DATE_FORMAT);
-	const wxString& timeFormat = COptions::Get()->GetOption(OPTION_TIME_FORMAT);
-
-	if (dateFormat == _T("1"))
-		m_dateFormat = _T("%Y-%m-%d");
-	else if (dateFormat[0] == '2')
-		m_dateFormat = dateFormat.Mid(1);
-	else
-		m_dateFormat = _T("%x");
-
-	m_dateFormat += ' ';
-
-	if (timeFormat == _T("1"))
-		m_dateFormat += _T("%H:%M");
-	else if (timeFormat[0] == '2')
-		m_dateFormat += timeFormat.Mid(1);
-	else
-		m_dateFormat += _T("%X");
-}
-
 wxListItemAttr* CLocalListView::OnGetItemAttr(long item) const
 {
 	CLocalListView *pThis = const_cast<CLocalListView *>(this);
@@ -1958,7 +1935,7 @@ wxString CLocalListView::GetItemText(int item, unsigned int column)
 		if (!data->hasTime)
 			return _T("");
 
-		return data->lastModified.Format(m_dateFormat);
+		return CTimeFormat::FormatDateTime(data->lastModified);
 	}
 	return _T("");
 }
