@@ -1,18 +1,18 @@
 #include <filezilla.h>
-
-#include "LocalTreeView.h"
-#include "LocalListView.h"
-#include "RemoteTreeView.h"
-#include "RemoteListView.h"
-#include "StatusView.h"
-#include "queue.h"
 #include "Mainfrm.h"
+
+#include "LocalListView.h"
+#include "LocalTreeView.h"
+#include "queue.h"
+#include "RemoteListView.h"
+#include "RemoteTreeView.h"
+#include "StatusView.h"
 #include "state.h"
 #include "Options.h"
-#include "commandqueue.h"
 #include "asyncrequestqueue.h"
+#include "commandqueue.h"
 #include "led.h"
-#include "sitemanager.h"
+#include "sitemanager_dialog.h"
 #include "settings/settingsdialog.h"
 #include "themeprovider.h"
 #include "filezillaapp.h"
@@ -49,6 +49,7 @@
 #include "speedlimits_dialog.h"
 #include "toolbar.h"
 #include "menu_bar.h"
+#include "string_coalescer.h"
 
 #ifdef __WXMSW__
 #include <wx/module.h>
@@ -623,6 +624,14 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 	{
 		CWrapEngine::ClearCache();
 	}
+	else if (event.GetId() == XRCID("ID_COALESCER_CLEAR"))
+	{
+		ClearStringCoalescer();
+	}
+	else if (event.GetId() == XRCID("ID_COALESCER_BENCHMARK"))
+	{
+		BenchmarkStringCoalescer();
+	}
 	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_FILEEXISTS"))
 	{
 		CDefaultFileExistsDlg dlg;
@@ -1340,14 +1349,14 @@ void CMainFrame::OpenSiteManager(const CServer* pServer /*=0*/)
 	if (!pState)
 		return;
 
-	CSiteManager dlg;
+	CSiteManagerDialog dlg;
 
 	std::set<wxString> handled_paths;
-	std::vector<CSiteManager::_connected_site> connected_sites;
+	std::vector<CSiteManagerDialog::_connected_site> connected_sites;
 
 	if (pServer)
 	{
-		CSiteManager::_connected_site connected_site;
+		CSiteManagerDialog::_connected_site connected_site;
 		connected_site.server = *pServer;
 		connected_sites.push_back(connected_site);
 	}
@@ -1364,7 +1373,7 @@ void CMainFrame::OpenSiteManager(const CServer* pServer /*=0*/)
 		if (handled_paths.find(path) != handled_paths.end())
 			continue;
 
-		CSiteManager::_connected_site connected_site;
+		CSiteManagerDialog::_connected_site connected_site;
 		connected_site.old_path = path;
 		connected_site.server = controls->pState->GetLastServer();
 		connected_sites.push_back(connected_site);
@@ -1392,7 +1401,7 @@ void CMainFrame::OpenSiteManager(const CServer* pServer /*=0*/)
 				controls->site_bookmarks->path = connected_sites[j].new_path;
 
 				controls->site_bookmarks->bookmarks.clear();
-				dlg.GetBookmarks(controls->site_bookmarks->path, controls->site_bookmarks->bookmarks);
+				CSiteManager::GetBookmarks(controls->site_bookmarks->path, controls->site_bookmarks->bookmarks);
 
 				break;
 			}
@@ -1599,7 +1608,7 @@ void CMainFrame::ShowLocalTree()
 			continue;
 
 		controls->pLocalTreeViewPanel->SetHeader(controls->pLocalListViewPanel->DetachHeader());
-		wxSize size = controls->pLocalSplitter->GetClientSize();
+		
 		if (layout == 3 && swap)
 			controls->pLocalSplitter->SplitVertically(controls->pLocalListViewPanel, controls->pLocalTreeViewPanel);
 		else if (layout)
@@ -1655,7 +1664,7 @@ void CMainFrame::ShowRemoteTree()
 			continue;
 
 		controls->pRemoteTreeViewPanel->SetHeader(controls->pRemoteListViewPanel->DetachHeader());
-		wxSize size = controls->pRemoteSplitter->GetClientSize();
+
 		if (layout == 3 && !swap)
 			controls->pRemoteSplitter->SplitVertically(controls->pRemoteListViewPanel, controls->pRemoteTreeViewPanel);
 		else if (layout)
@@ -1701,13 +1710,9 @@ void CMainFrame::OnToggleQueueView(wxCommandEvent& event)
 	else
 	{
 		if (m_pBottomSplitter->IsSplit())
-		{
-			wxRect rect = m_pBottomSplitter->GetClientSize();
 			m_pBottomSplitter->Unsplit(m_pQueueLogSplitter);
-		}
 		else
 		{
-			wxRect rect = m_pBottomSplitter->GetClientSize();
 			m_pQueueLogSplitter->Initialize(m_pQueuePane);
 			m_pBottomSplitter->SplitHorizontally(m_pContextControl, m_pQueueLogSplitter);
 		}
@@ -2010,13 +2015,6 @@ void CMainFrame::CheckChangedSettings()
 
 	m_pAsyncRequestQueue->RecheckDefaults();
 
-	CContextControl::_context_controls* controls = m_pContextControl->GetCurrentControls();
-	if (controls)
-	{
-		controls->pLocalListView->InitDateFormat();
-		controls->pRemoteListView->InitDateFormat();
-	}
-
 	m_pQueueView->SettingsChanged();
 	CAutoAsciiFiles::SettingsChanged();
 }
