@@ -34,7 +34,8 @@ enum Flags
 {
 	normal,
 	internal,
-	default_only
+	default_only,
+	default_priority // If that option is given in fzdefaults.xml, it overrides any user option
 };
 
 struct t_Option
@@ -174,10 +175,11 @@ static const t_Option options[OPTIONS_NUM] =
 	{ "Edit status dialog size", string, _T(""), normal },
 	{ "Display current speed", number, _T("0"), normal },
 	{ "Toolbar hidden", number, _T("0"), normal },
+	{ "Strip VMS revisions", number, _T("0"), normal },
 
 	// Default/internal options
 	{ "Config Location", string, _T(""), default_only },
-	{ "Kiosk mode", number, _T("0"), default_only },
+	{ "Kiosk mode", number, _T("0"), default_priority },
 	{ "Disable update check", number, _T("0"), default_only }
 };
 
@@ -325,6 +327,14 @@ bool COptions::SetOption(unsigned int nID, wxString value)
 	return true;
 }
 
+bool COptions::OptionFromFzDefaultsXml(unsigned int nID)
+{
+	if (nID >= OPTIONS_NUM)
+		return false;
+
+	return m_optionsCache[nID].from_default;
+}
+
 void COptions::CreateSettingsXmlElement()
 {
 	if (!m_pXmlFile)
@@ -684,7 +694,6 @@ void COptions::LoadOptionFromElement(TiXmlElement* pOption, const std::map<std::
 	{
 		if (!allowDefault && options[iter->second].flags == default_only)
 			return;
-
 		wxString value;
 
 		TiXmlNode *text = pOption->FirstChild();
@@ -695,6 +704,17 @@ void COptions::LoadOptionFromElement(TiXmlElement* pOption, const std::map<std::
 			value = ConvLocal(text->Value());
 		}
 
+		if (options[iter->second].flags == default_priority)
+		{
+			if (allowDefault)
+				m_optionsCache[iter->second].from_default = true;
+			else
+			{
+				if (m_optionsCache[iter->second].from_default)
+					return;
+			}
+		}
+
 		if (options[iter->second].type == number)
 		{
 			long numValue = 0;
@@ -831,5 +851,6 @@ void COptions::SetDefaultValues()
 			options[i].defaultValue.ToLong(&numValue);
 			m_optionsCache[i].numValue = numValue;
 		}
+		m_optionsCache[i].from_default = false;
 	}
 }
