@@ -80,6 +80,7 @@ enum interfaceOptions
 	OPTION_EDITSTATUSDIALOG_SIZE,
 	OPTION_SPEED_DISPLAY,
 	OPTION_TOOLBAR_HIDDEN,
+	OPTION_STRIP_VMS_REVISION,
 
 	// Default/internal options
 	OPTION_DEFAULT_SETTINGSDIR,
@@ -92,7 +93,7 @@ enum interfaceOptions
 
 struct t_OptionsCache
 {
-	bool cached;
+	bool from_default;
 	int numValue;
 	wxString strValue;
 };
@@ -107,6 +108,8 @@ public:
 
 	virtual bool SetOption(unsigned int nID, int value);
 	virtual bool SetOption(unsigned int nID, wxString value);
+
+	bool OptionFromFzDefaultsXml(unsigned int nID);
 	
 	void SetLastServer(const CServer& server);
 	bool GetLastServer(CServer& server);
