@@ -203,6 +203,11 @@ END_EVENT_TABLE()
 
 class CFolderProcessingThread : public wxThread
 {
+	struct t_internalDirPair
+	{
+		wxString localPath;
+		CServerPath remotePath;
+	};
 public:
 	CFolderProcessingThread(CQueueView* pOwner, CFolderScanItem* pFolderItem)
 		: wxThread(wxTHREAD_JOINABLE), m_condition(m_sync) {
@@ -214,9 +219,9 @@ public:
 		m_throttleWait = false;
 		m_processing_entries = false;
 
-		t_dirPair* pair = new t_dirPair;
+		t_internalDirPair* pair = new t_internalDirPair;
 		pair->localPath = pFolderItem->GetLocalPath().GetPath().c_str();
-		pair->remotePath.SetSafePath(pFolderItem->GetRemotePath().GetSafePath().c_str());
+		pair->remotePath.SetSafePath(pFolderItem->GetRemotePath().GetSafePath().c_str(), false);
 		m_dirsToCheck.push_back(pair);
 	}
 
@@ -224,7 +229,7 @@ public:
 	{
 		for (std::list<CFolderProcessingEntry*>::iterator iter = m_entryList.begin(); iter != m_entryList.end(); iter++)
 			delete *iter;
-		for (std::list<t_dirPair*>::iterator iter = m_dirsToCheck.begin(); iter != m_dirsToCheck.end(); iter++)
+		for (std::list<t_internalDirPair*>::iterator iter = m_dirsToCheck.begin(); iter != m_dirsToCheck.end(); iter++)
 			delete *iter;
 	}
 
@@ -249,20 +254,20 @@ public:
 	public:
 		t_dirPair() : CFolderProcessingEntry(CFolderProcessingEntry::dir) {}
 		wxString localPath;
-		CServerPath remotePath;
+		wxString remotePath;
 	};
 
 	void ProcessDirectory(const CLocalPath& localPath, CServerPath remotePath, const wxString& name)
 	{
 		wxMutexLocker locker(m_sync);
 
-		t_dirPair* pair = new t_dirPair;
+		t_internalDirPair* pair = new t_internalDirPair;
 
 		{
 			pair->localPath = (localPath.GetPath() + name).c_str();
 
 			remotePath.AddSegment(name);
-			pair->remotePath.SetSafePath(remotePath.GetSafePath().c_str());
+			pair->remotePath.SetSafePath(remotePath.GetSafePath().c_str(), false);
 		}
 
 		m_dirsToCheck.push_back(pair);
@@ -381,7 +386,7 @@ protected:
 				continue;
 			}
 
-			const t_dirPair *pair = m_dirsToCheck.front();
+			const t_internalDirPair *pair = m_dirsToCheck.front();
 			m_dirsToCheck.pop_front();
 
 			m_sync.Unlock();
@@ -396,7 +401,7 @@ protected:
 	
 			{
 				pair2->localPath = pair->localPath.c_str();
-				pair2->remotePath.SetSafePath(pair->remotePath.GetSafePath().c_str());
+				pair2->remotePath = pair->remotePath.GetSafePath().c_str();
 			}
 
 			AddEntry(pair2);
@@ -428,7 +433,7 @@ protected:
 		return 0;
 	}
 
-	std::list<t_dirPair*> m_dirsToCheck;
+	std::list<t_internalDirPair*> m_dirsToCheck;
 
 	// Access has to be guarded by m_sync
 	std::list<CFolderProcessingEntry*> m_entryList;
@@ -471,7 +476,9 @@ CQueueView::CQueueView(CQueue* parent, int index, CMainFrame* pMainFrame, CAsync
 	m_actionAfterTimerId = -1;
 #endif
 
-	CreateColumns(_("Status"));
+	std::list<ColumnId> extraCols;
+	extraCols.push_back(colTransferStatus);
+	CreateColumns(extraCols);
 
 	//Initialize the engine data
 	t_EngineData *pData = new t_EngineData;
@@ -520,32 +527,32 @@ CQueueView::~CQueueView()
 }
 
 bool CQueueView::QueueFile(const bool queueOnly, const bool download,
-						   const CLocalPath& localPath, const wxString& localFile,
-						   const wxString& remoteFile, const CServerPath& remotePath,
+						   const wxString& sourceFile, const wxString& targetFile,
+						   const CLocalPath& localPath, const CServerPath& remotePath,
 						   const CServer& server, const wxLongLong size, enum CEditHandler::fileType edit /*=CEditHandler::none*/)
 {
 	CServerItem* pServerItem = CreateServerItem(server);
 
 	CFileItem* fileItem;
-	if (localFile == _T("") || remotePath.IsEmpty())
+	if (sourceFile.empty())
 	{
 		if (download)
 		{
 			CLocalPath p(localPath);
-			p.AddSegment(localFile);
+			p.AddSegment(targetFile);
 			fileItem = new CFolderItem(pServerItem, queueOnly, p);
 		}
 		else
-			fileItem = new CFolderItem(pServerItem, queueOnly, remotePath, remoteFile);
+			fileItem = new CFolderItem(pServerItem, queueOnly, remotePath, targetFile);
 		wxASSERT(edit == CEditHandler::none);
 	}
 	else
 	{
-		fileItem = new CFileItem(pServerItem, queueOnly, download, localPath, localFile, remoteFile, remotePath, size);
+		fileItem = new CFileItem(pServerItem, queueOnly, download, sourceFile, targetFile, localPath, remotePath, size);
 		if (download)
-			fileItem->m_transferSettings.binary = !CAutoAsciiFiles::TransferRemoteAsAscii(remoteFile, remotePath.GetType());
+			fileItem->m_transferSettings.binary = !CAutoAsciiFiles::TransferRemoteAsAscii(sourceFile, remotePath.GetType());
 		else
-			fileItem->m_transferSettings.binary = !CAutoAsciiFiles::TransferLocalAsAscii(localFile, remotePath.GetType());
+			fileItem->m_transferSettings.binary = !CAutoAsciiFiles::TransferLocalAsAscii(sourceFile, remotePath.GetType());
 		fileItem->m_edit = edit;
 		if (edit != CEditHandler::none)
 			fileItem->m_onetime_action = CFileExistsNotification::overwrite;
@@ -582,6 +589,9 @@ void CQueueView::QueueFile_Finish(const bool start)
 		RefreshListOnly(false);
 }
 
+// Defined in RemoteListView.cpp
+extern wxString StripVMSRevision(const wxString& name);
+
 bool CQueueView::QueueFiles(const bool queueOnly, const CLocalPath& localPath, const CRemoteDataObject& dataObject)
 {
 	CServerItem* pServerItem = CreateServerItem(dataObject.GetServer());
@@ -594,7 +604,13 @@ bool CQueueView::QueueFiles(const bool queueOnly, const CLocalPath& localPath, c
 			continue;
 
 		CFileItem* fileItem;
-		fileItem = new CFileItem(pServerItem, queueOnly, true, localPath, ReplaceInvalidCharacters(iter->name), iter->name, dataObject.GetServerPath(), iter->size);
+		wxString localFile = ReplaceInvalidCharacters(iter->name);
+		if (dataObject.GetServerPath().GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+			localFile = StripVMSRevision(localFile);
+
+		fileItem = new CFileItem(pServerItem, queueOnly, true,
+			iter->name, (iter->name != localFile) ? localFile : wxString(),
+			localPath, dataObject.GetServerPath(), iter->size);
 		fileItem->m_transferSettings.binary = !CAutoAsciiFiles::TransferRemoteAsAscii(iter->name, dataObject.GetServerPath().GetType());
 
 		InsertItem(pServerItem, fileItem);
@@ -1043,7 +1059,7 @@ void CQueueView::ProcessReply(t_EngineData* pEngineData, COperationNotification*
 				CLoginManager::Get().CachedPasswordFailed(pEngineData->lastServer);
 
 			if ((replyCode & FZ_REPLY_CANCELED) == FZ_REPLY_CANCELED)
-				pEngineData->pItem->m_statusMessage = _T("");
+				pEngineData->pItem->m_statusMessage.clear();
 			else if (replyCode & FZ_REPLY_PASSWORDFAILED)
 				pEngineData->pItem->m_statusMessage = _("Incorrect password");
 			else if ((replyCode & FZ_REPLY_TIMEOUT) == FZ_REPLY_TIMEOUT)
@@ -1089,7 +1105,7 @@ void CQueueView::ProcessReply(t_EngineData* pEngineData, COperationNotification*
 		else
 		{
 			if ((replyCode & FZ_REPLY_CANCELED) == FZ_REPLY_CANCELED)
-				pEngineData->pItem->m_statusMessage = _T("");
+				pEngineData->pItem->m_statusMessage.clear();
 			else if ((replyCode & FZ_REPLY_TIMEOUT) == FZ_REPLY_TIMEOUT)
 				pEngineData->pItem->m_statusMessage = _("Timeout");
 			else if (replyCode & FZ_REPLY_DISCONNECTED)
@@ -1278,6 +1294,7 @@ void CQueueView::ResetEngine(t_EngineData& data, const enum ResetReason reason)
 				CQueueViewFailed* pQueueViewFailed = m_pQueue->GetQueueView_Failed();
 				CServerItem* pServerItem = pQueueViewFailed->CreateServerItem(server);
 				data.pItem->SetParent(pServerItem);
+				data.pItem->UpdateTime();
 				pQueueViewFailed->InsertItem(pServerItem, data.pItem);
 				pQueueViewFailed->CommitChanges();
 			}
@@ -1296,6 +1313,7 @@ void CQueueView::ResetEngine(t_EngineData& data, const enum ResetReason reason)
 					RemoveItem(data.pItem, false);
 
 					CServerItem* pServerItem = pQueueViewSuccessful->CreateServerItem(server);
+					data.pItem->UpdateTime();
 					data.pItem->SetParent(pServerItem);
 					pQueueViewSuccessful->InsertItem(pServerItem, data.pItem);
 					pQueueViewSuccessful->CommitChanges();
@@ -1872,7 +1890,7 @@ int CQueueView::QueueFiles(const std::list<CFolderProcessingEntry*> &entryList,
 
 			const CFolderProcessingThread::t_dirPair* entry = (const CFolderProcessingThread::t_dirPair*)*iter;
 			pFolderScanItem->m_current_local_path = CLocalPath(entry->localPath);
-			pFolderScanItem->m_current_remote_path = entry->remotePath;
+			pFolderScanItem->m_current_remote_path.SetSafePath(entry->remotePath);
 			pFolderScanItem->m_dir_is_empty = true;
 			delete entry;
 		}
@@ -1895,7 +1913,7 @@ int CQueueView::QueueFiles(const std::list<CFolderProcessingEntry*> &entryList,
 				continue;
 			}
 
-			CFileItem* fileItem = new CFileItem(pServerItem, queueOnly, download, pFolderScanItem->m_current_local_path, entry->name, entry->name, pFolderScanItem->m_current_remote_path, entry->size);
+			CFileItem* fileItem = new CFileItem(pServerItem, queueOnly, download, entry->name, wxEmptyString, pFolderScanItem->m_current_local_path, pFolderScanItem->m_current_remote_path, entry->size);
 
 			if (download)
 				fileItem->m_transferSettings.binary = !CAutoAsciiFiles::TransferRemoteAsAscii(entry->name, pFolderScanItem->m_current_remote_path.GetType());
@@ -1919,48 +1937,33 @@ int CQueueView::QueueFiles(const std::list<CFolderProcessingEntry*> &entryList,
 
 void CQueueView::SaveQueue()
 {
-	// Kiosk mode doesn't save queue
+	// Kiosk mode 2 doesn't save queue
 	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) == 2)
 		return;
 
-	// We have to synchronize access to queue.xml so that multiple processed don't write
-	// to the same file or one is reading while the other one writes.
+	// While not really needed anymore using sqlite3, we still take the mutex
+	// just as extra precaution. Better 'save' than sorry.
 	CInterProcessMutex mutex(MUTEX_QUEUE);
 
-	wxFileName file(COptions::Get()->GetOption(OPTION_DEFAULT_SETTINGSDIR), _T("queue.xml"));
-	CXmlFile xml(file);
-	TiXmlElement* pDocument = xml.Load();
-	if (!pDocument)
+	if (!m_queue_storage.SaveQueue(m_serverList))
 	{
-		wxString msg = xml.GetError() + _T("\n\n") + _("The queue will not be saved.");
-		wxMessageBox(msg, _("Error loading xml file"), wxICON_ERROR);
-
-		return;
-	}
-
-	WriteToFile(pDocument);
-
-	wxString error;
-	if (!xml.Save(&error))
-	{
-		wxString msg = wxString::Format(_("Could not write \"%s\", the queue could not be saved.\n%s"), file.GetFullPath().c_str(), error.c_str());
-		wxMessageBox(msg, _("Error writing xml file"), wxICON_ERROR);
+		wxString msg = wxString::Format(_("An error occurred saving the transfer queue to \"%s\".\nSome queue items might not have been saved."), m_queue_storage.GetDatabaseFilename().c_str());
+		wxMessageBox(msg, _("Error saving queue"), wxICON_ERROR);
 	}
 }
 
-void CQueueView::LoadQueue()
+void CQueueView::LoadQueueFromXML()
 {
-	// We have to synchronize access to queue.xml so that multiple processed don't write
-	// to the same file or one is reading while the other one writes.
-	CInterProcessMutex mutex(MUTEX_QUEUE);
-
 	wxFileName file(COptions::Get()->GetOption(OPTION_DEFAULT_SETTINGSDIR), _T("queue.xml"));
 	CXmlFile xml(file);
-	TiXmlElement* pDocument = xml.Load();
+	TiXmlElement* pDocument = xml.Load(wxFileName(), false);
 	if (!pDocument)
 	{
-		wxString msg = xml.GetError() + _T("\n\n") + _("The queue will not be saved.");
-		wxMessageBox(msg, _("Error loading xml file"), wxICON_ERROR);
+		if (!xml.GetError().empty())
+		{
+			wxString msg = xml.GetError() + _T("\n\n") + _("The queue will not be saved.");
+			wxMessageBox(msg, _("Error loading xml file"), wxICON_ERROR);
+		}
 
 		return;
 	}
@@ -1984,6 +1987,72 @@ void CQueueView::LoadQueue()
 	}
 }
 
+void CQueueView::LoadQueue()
+{
+	// We have to synchronize access to queue.xml so that multiple processed don't write
+	// to the same file or one is reading while the other one writes.
+	CInterProcessMutex mutex(MUTEX_QUEUE);
+
+	LoadQueueFromXML();
+
+	bool error = false;
+
+	if (!m_queue_storage.BeginTransaction())
+		error = true;
+	else
+	{
+		CServer server;
+		wxLongLong_t id;
+		for (id = m_queue_storage.GetServer(server, true); id > 0; id = m_queue_storage.GetServer(server, false))
+		{
+			m_insertionStart = -1;
+			m_insertionCount = 0;
+			CServerItem *pServerItem = CreateServerItem(server);
+
+			CFileItem* fileItem = 0;
+			wxLongLong_t fileId;
+			for (fileId = m_queue_storage.GetFile(&fileItem, id); fileItem; fileId = m_queue_storage.GetFile(&fileItem, 0))
+			{
+				fileItem->SetParent(pServerItem);
+				fileItem->SetPriority(fileItem->GetPriority());
+				InsertItem(pServerItem, fileItem);
+			}
+			if (fileId < 0)
+				error = true;
+
+			if (!pServerItem->GetChild(0))
+			{
+				m_itemCount--;
+				m_serverList.pop_back();
+				delete pServerItem;
+			}
+		}
+		if (id < 0)
+			error = true;
+
+		if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 2)
+			if (!m_queue_storage.Clear())
+				error = true;
+
+		if (!m_queue_storage.EndTransaction())
+			error = true;
+
+		if (!m_queue_storage.Vacuum())
+			error = true;
+	}
+	
+	m_insertionStart = -1;
+	m_insertionCount = 0;
+	CommitChanges();
+
+	if (error)
+	{
+		wxString file = CQueueStorage::GetDatabaseFilename();
+		wxString msg = wxString::Format(_("An error occurred loading the transfer queue from \"%s\".\nSome queue items might not have been restored."), file.c_str());
+		wxMessageBox(msg, _("Error loading queue"), wxICON_ERROR);
+	}
+}
+
 void CQueueView::ImportQueue(TiXmlElement* pElement, bool updateSelections)
 {
 	TiXmlElement* pServer = pElement->FirstChildElement("Server");
@@ -2008,7 +2077,11 @@ void CQueueView::ImportQueue(TiXmlElement* pElement, bool updateSelections)
 				wxLongLong size = GetTextElementLongLong(pFile, "Size", -1);
 				unsigned int errorCount = GetTextElementInt(pFile, "ErrorCount");
 				unsigned int priority = GetTextElementInt(pFile, "Priority", priority_normal);
-				bool binary = GetTextElementInt(pFile, "TransferMode", 1) != 0;
+
+				int dataType = GetTextElementInt(pFile, "DataType", -1);
+				if (dataType == -1)
+					dataType = GetTextElementInt(pFile, "TransferMode", 1); 
+				bool binary = dataType != 0;
 				int overwrite_action = GetTextElementInt(pFile, "OverwriteAction", CFileExistsNotification::unknown);
 
 				CServerPath remotePath;
@@ -2028,7 +2101,10 @@ void CQueueView::ImportQueue(TiXmlElement* pElement, bool updateSelections)
 					if (previousRemotePath != remotePath)
 						previousRemotePath = remotePath;
 
-					CFileItem* fileItem = new CFileItem(pServerItem, true, download, localPath, localFileName, remoteFile, previousRemotePath, size);
+					CFileItem* fileItem = new CFileItem(pServerItem, true, download,
+						download ? remoteFile : localFileName,
+						(remoteFile != localFileName) ? (download ? localFileName : remoteFile) : wxString(),
+						previousLocalPath, previousRemotePath, size);
 					fileItem->m_transferSettings.binary = binary;
 					fileItem->SetPriorityRaw((enum QueuePriority)priority);
 					fileItem->m_errorCount = errorCount;
@@ -2265,6 +2341,17 @@ void CQueueView::RemoveAll()
 			m_itemCount += 1 + (*iter)->GetChildrenCount(true);
 		}
 	}
+
+	// Clear list of queued directories that aren't busy
+	for (unsigned int i = 0; i < 2; i++)
+	{
+		std::list<CFolderScanItem*>::iterator begin = m_queuedFolders[i].begin();
+		std::list<CFolderScanItem*>::iterator end = m_queuedFolders[i].end();
+		if (begin != end && (*begin)->m_active)
+			++begin;
+		m_queuedFolders[i].erase(begin, end);
+	}
+
 	SaveSetItemCount(m_itemCount);
 	m_actionAfterState = ActionAfterState_Disabled;
 
@@ -2277,6 +2364,21 @@ void CQueueView::RemoveAll()
 	RefreshListOnly();
 }
 
+void CQueueView::RemoveQueuedFolderItem(CFolderScanItem* pFolder)
+{
+	for (unsigned int i = 0; i < 2; i++)
+	{
+		for (std::list<CFolderScanItem*>::iterator iter = m_queuedFolders[i].begin(); iter != m_queuedFolders[i].end(); iter++)
+		{
+			if (*iter != pFolder)
+				continue;
+
+			m_queuedFolders[i].erase(iter);
+			return;
+		}
+	}
+}
+
 void CQueueView::OnRemoveSelected(wxCommandEvent& event)
 {
 #ifndef __WXMSW__
@@ -2314,6 +2416,8 @@ void CQueueView::OnRemoveSelected(wxCommandEvent& event)
 				pFolder->m_remove = true;
 				continue;
 			}
+			else
+				RemoveQueuedFolderItem(pFolder);
 		}
 		else if (pItem->GetType() == QueueItemType_Server)
 		{
@@ -2370,7 +2474,7 @@ bool CQueueView::StopItem(CFileItem* item)
 		else
 			reason = reset;
 		if (item->m_pEngineData->pItem)
-			item->m_pEngineData->pItem->m_statusMessage = _T("");
+			item->m_pEngineData->pItem->m_statusMessage.clear();
 		ResetEngine(*item->m_pEngineData, reason);
 		return true;
 	}
@@ -3064,6 +3168,7 @@ void CQueueView::ActionAfter(bool warned /*=false*/)
 			wxMessageDialog* dialog = new wxMessageDialog(m_pMainFrame, _("No more files in the queue!"), _T("Queue completion"), wxOK | wxICON_INFORMATION);
 			m_pMainFrame->RequestUserAttention(wxUSER_ATTENTION_ERROR);
 			dialog->ShowModal();
+			dialog->Destroy();
 			break;
 		}
 		case ActionAfterState_PlaySound:
@@ -3117,7 +3222,6 @@ void CQueueView::ActionAfterWarnUser(bool shutdown)
 		message = _("The system will soon reboot unless you click Cancel.");
 
 	m_actionAfterWarnDialog = new wxProgressDialog(_("Queue has been fully processed"), message, 150, m_pMainFrame, wxPD_CAN_ABORT | wxPD_AUTO_HIDE | wxPD_CAN_SKIP | wxPD_APP_MODAL);
-	wxSize dialogSize = m_actionAfterWarnDialog->GetSize();
 
 	// Magic id from wxWidgets' src/generic/propdlgg.cpp
 	wxWindow* pSkip = m_actionAfterWarnDialog->FindWindow(32000);
@@ -3288,7 +3392,7 @@ int CQueueView::GetLineHeight()
 	m_line_height = rect.GetHeight();
 
 #ifdef __WXMSW__
-	m_header_height = rect.y;
+	m_header_height = rect.y + GetScrollPos(wxVERTICAL) * m_line_height;
 #endif
 
 	return m_line_height;
@@ -3297,7 +3401,7 @@ int CQueueView::GetLineHeight()
 void CQueueView::OnSize(wxSizeEvent& event)
 {
 	if (!m_resize_timer.IsRunning())
-		m_resize_timer.Start(250);
+		m_resize_timer.Start(250, true);
 
 	event.Skip();
 }
@@ -3325,10 +3429,10 @@ void CQueueView::RenameFileInTransfer(CFileZillaEngine *pEngine, const wxString&
 	{
 		wxFileName fn(pFile->GetLocalPath().GetPath(), pFile->GetLocalFile());
 		fn.SetFullName(newName);
-		pFile->SetLocalFile(fn.GetFullName());
+		pFile->SetTargetFile(fn.GetFullName());
 	}
 	else
-		pFile->SetRemoteFile(newName);
+		pFile->SetTargetFile(newName);
 
 	RefreshItem(pFile);
 }
@@ -3342,7 +3446,8 @@ wxString CQueueView::ReplaceInvalidCharacters(const wxString& filename)
 
 	wxString result;
 
-	wxChar* buf = result.GetWriteBuf(filename.Len() + 1);
+	wxChar* start = result.GetWriteBuf(filename.Len() + 1);
+	wxChar* buf = start;
 
 	const wxChar* p = filename.c_str();
 	while (*p)
@@ -3378,7 +3483,7 @@ wxString CQueueView::ReplaceInvalidCharacters(const wxString& filename)
 	}
 	*buf = 0;
 
-	result.UngetWriteBuf();
+	result.UngetWriteBuf( buf - start );
 
 	return result;
 }
@@ -3402,3 +3507,31 @@ void CQueueView::ReleaseExclusiveEngineLock(CFileZillaEngine* pEngine)
 		break;
 	}
 }
+
+#ifdef __WXMSW__
+
+#ifndef WM_DWMCOMPOSITIONCHANGED
+#define WM_DWMCOMPOSITIONCHANGED        0x031E
+#endif // WM_DWMCOMPOSITIONCHANGED
+
+WXLRESULT CQueueView::MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lParam)
+{
+	if (nMsg == WM_DWMCOMPOSITIONCHANGED || nMsg == WM_THEMECHANGED)
+	{
+		m_line_height = -1;
+		if (!m_resize_timer.IsRunning())
+			m_resize_timer.Start(250, true);
+	}
+	else if (nMsg == WM_LBUTTONDOWN)
+	{
+		// If clicking a partially selected item, Windows starts an internal timer with the double-click interval (as seen in the 
+		// disassembly). After the timer expires, the given item is selected. But there's a huge bug in Windows: We don't get
+		// notified about this change in scroll position in any way (verified using Spy++), so on left button down, start our
+		// own timer with a slightly higher interval.
+		if (!m_resize_timer.IsRunning())
+			m_resize_timer.Start(GetDoubleClickTime() + 5, true);
+	}
+	return CQueueViewBase::MSWWindowProc(nMsg, wParam, lParam);
+}
+
+#endif
