@@ -9,6 +9,8 @@
 #include <set>
 #include <wx/progdlg.h>
 
+#include "queue_storage.h"
+
 class CFolderProcessingEntry
 {
 public:
@@ -93,8 +95,11 @@ public:
 	CQueueView(CQueue* parent, int index, CMainFrame* pMainFrame, CAsyncRequestQueue* pAsyncRequestQueue);
 	virtual ~CQueueView();
 
-	bool QueueFile(const bool queueOnly, const bool download, const CLocalPath& localPath, const wxString& localFile, const wxString& remoteFile,
-	const CServerPath& remotePath, const CServer& server, const wxLongLong size, enum CEditHandler::fileType edit = CEditHandler::none);
+	bool QueueFile(const bool queueOnly, const bool download,
+		const wxString& localFile, const wxString& remoteFile,
+		const CLocalPath& localPath, const CServerPath& remotePath,
+		const CServer& server, const wxLongLong size, enum CEditHandler::fileType edit = CEditHandler::none);
+
 	void QueueFile_Finish(const bool start); // Need to be called after QueueFile
 	bool QueueFiles(const bool queueOnly, const CLocalPath& localPath, const CRemoteDataObject& dataObject);
 	int QueueFiles(const std::list<CFolderProcessingEntry*> &entryList, bool queueOnly, bool download, CServerItem* pServerItem, const enum CFileExistsNotification::OverwriteAction defaultFileExistsAction);
@@ -118,6 +123,7 @@ public:
 	void RemoveAll();
 
 	void LoadQueue();
+	void LoadQueueFromXML();
 	void ImportQueue(TiXmlElement* pElement, bool updateSelections);
 
 	virtual void InsertItem(CServerItem* pServerItem, CQueueItem* pItem);
@@ -134,6 +140,10 @@ public:
 
 protected:
 
+#ifdef __WXMSW__
+	WXLRESULT MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lParam);
+#endif
+
 	void AdvanceQueue(bool refresh = true);
 	bool TryStartNextTransfer();
 
@@ -210,6 +220,8 @@ protected:
 	 */
 	std::list<CFolderScanItem*> m_queuedFolders[2];
 
+	void RemoveQueuedFolderItem(CFolderScanItem* pFolder);
+
 	CFolderProcessingThread *m_pFolderProcessingThread;
 	
 	/*
@@ -263,6 +275,8 @@ protected:
 	CDesktopNotification* m_desktop_notification;
 #endif
 
+	CQueueStorage m_queue_storage;
+
 	DECLARE_EVENT_TABLE();
 	void OnEngineEvent(wxEvent &event);
 	void OnFolderThreadComplete(wxCommandEvent& event);
