@@ -18,6 +18,7 @@
 #include "dragdropmanager.h"
 #include <wx/clipbrd.h>
 #include "sizeformatting.h"
+#include "timeformatting.h"
 #ifdef __WXMSW__
 #include "shellapi.h"
 #include "commctrl.h"
@@ -373,12 +374,9 @@ CRemoteListView::CRemoteListView(wxWindow* pParent, CState *pState, CQueueView*
 
 	SetDropTarget(new CRemoteListViewDropTarget(this));
 
-	InitDateFormat();
-
 	EnablePrefixSearch(true);
 
 	m_pLinkResolveState = 0;
-
 }
 
 CRemoteListView::~CRemoteListView()
@@ -1157,6 +1155,32 @@ public:
 };
 typedef CReverseSort<CRemoteListViewSortOwnerGroup> CRemoteListViewSortOwnerGroup_Reverse;
 
+// Filenames on VMS systems have a revision suffix, e.g.
+// foo.bar;1
+// foo.bar;2
+// foo.bar;3
+wxString StripVMSRevision(const wxString& name)
+{
+	int pos = name.Find(';', true);
+	if (pos < 1)
+		return name;
+
+	const int len = name.Len();
+	if (pos == len - 1)
+		return name;
+
+	int p = pos;
+	while (++p < len)
+	{
+		const wxChar& c = name[p];
+		if (c < '0' || c > '9')
+			return name;
+	}
+
+	return name.Left(pos);
+}
+
+
 void CRemoteListView::OnItemActivated(wxListEvent &event)
 {
 	if (!m_pState->IsRemoteIdle())
@@ -1278,7 +1302,12 @@ void CRemoteListView::OnItemActivated(wxListEvent &event)
 				return;
 			}
 
-			m_pQueue->QueueFile(queue_only, true, local_path, CQueueView::ReplaceInvalidCharacters(name), name, m_pDirectoryListing->path, *pServer, entry.size);
+			wxString localFile = CQueueView::ReplaceInvalidCharacters(name);
+			if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+				localFile = StripVMSRevision(localFile);
+			m_pQueue->QueueFile(queue_only, true, name,
+				(name == localFile) ? wxString() : localFile,
+				local_path, m_pDirectoryListing->path, *pServer, entry.size);
 			m_pQueue->QueueFile_Finish(true);
 		}
 	}
@@ -1542,7 +1571,12 @@ void CRemoteListView::TransferSelectedFiles(const CLocalPath& local_parent, bool
 		}
 		else
 		{
-			m_pQueue->QueueFile(queueOnly, true, local_parent, CQueueView::ReplaceInvalidCharacters(name), name, m_pDirectoryListing->path, *pServer, entry.size);
+			wxString localFile = CQueueView::ReplaceInvalidCharacters(name);
+			if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+				localFile = StripVMSRevision(localFile);
+			m_pQueue->QueueFile(queueOnly, true,
+				name, (name == localFile) ? wxString() : localFile,
+				local_parent, m_pDirectoryListing->path, *pServer, entry.size);
 			added = true;
 		}
 	}
@@ -2438,7 +2472,7 @@ void CRemoteListView::OnBeginDrag(wxListEvent& event)
 	}
 #endif
 
-	CLabelEditBlocker(*this);
+	CLabelEditBlocker b(*this);
 
 	wxDropSource source(this);
 	source.SetData(object);
@@ -2456,8 +2490,6 @@ void CRemoteListView::OnBeginDrag(wxListEvent& event)
 		return;
 	}
 
-	const wxDataFormat fmt = object.GetReceivedFormat();
-
 #if FZ3_USESHELLEXT
 	if (ext)
 	{
@@ -2528,25 +2560,6 @@ void CRemoteListView::OnBeginDrag(wxListEvent& event)
 #endif
 }
 
-void CRemoteListView::InitDateFormat()
-{
-	const wxString& dateFormat = COptions::Get()->GetOption(OPTION_DATE_FORMAT);
-	const wxString& timeFormat = COptions::Get()->GetOption(OPTION_TIME_FORMAT);
-
-	if (dateFormat == _T("1"))
-		m_dateFormat = _T("%Y-%m-%d");
-	else if (dateFormat[0] == '2')
-		m_dateFormat = dateFormat.Mid(1);
-	else
-		m_dateFormat = _T("%x");
-
-	if (timeFormat == _T("1"))
-		m_timeFormat = m_dateFormat + _T(" %H:%M");
-	else if (timeFormat[0] == '2')
-		m_timeFormat = m_dateFormat + _T(" ") + timeFormat.Mid(1);
-	else
-		m_timeFormat = m_dateFormat + _T(" %X");
-}
 
 void CRemoteListView::OnMenuEdit(wxCommandEvent& event)
 {
@@ -2661,7 +2674,7 @@ void CRemoteListView::OnMenuEdit(wxCommandEvent& event)
 			wxMessageBox(_("A file with that name is already being transferred."), _("Cannot view/edit selected file"), wxICON_EXCLAMATION);
 			continue;
 		case CEditHandler::removing:
-			if (!pEditHandler)
+			if (!pEditHandler->Remove(entry.name, path, server))
 			{
 				wxMessageBox(_("A file with that name is still being edited. Please close it and try again."), _("Selected file is already opened"), wxICON_EXCLAMATION);
 				continue;
@@ -2712,7 +2725,8 @@ void CRemoteListView::OnMenuEdit(wxCommandEvent& event)
 		wxString localFile;
 		CLocalPath localPath(file, &localFile);
 
-		m_pQueue->QueueFile(false, true, localPath, localFile, entry.name, path, server, entry.size, CEditHandler::remote);
+		m_pQueue->QueueFile(false, true, entry.name, (localFile != entry.name) ? localFile : wxString(),
+			localPath, path, server, entry.size, CEditHandler::remote);
 		m_pQueue->QueueFile_Finish(true);
 	}
 }
@@ -2721,7 +2735,7 @@ void CRemoteListView::OnMenuEdit(wxCommandEvent& event)
 void CRemoteListView::ValidateIndexMapping()
 {
 	// This ensures that the index mapping is a bijection.
-    // Beware:
+	// Beware:
 	// - NO filter may be used!
 	// - Doesn't work in comparison mode
 
@@ -2872,31 +2886,6 @@ wxListItemAttr* CRemoteListView::OnGetItemAttr(long item) const
 	return 0;
 }
 
-// Filenames on VMS systems have a revision suffix, e.g.
-// foo.bar;1
-// foo.bar;2
-// foo.bar;3
-wxString StripVMSRevision(const wxString& name)
-{
-	int pos = name.Find(';', true);
-	if (pos < 1)
-		return name;
-
-	const int len = name.Len();
-	if (pos == len - 1)
-		return name;
-
-	int p = pos;
-	while (++p < len)
-	{
-		const wxChar& c = name[p];
-		if (c < '0' || c > '9')
-			return name;
-	}
-
-	return name.Left(pos);
-}
-
 wxString CRemoteListView::GetItemText(int item, unsigned int column)
 {
 	int index = GetItemIndex(item);
@@ -2947,9 +2936,9 @@ wxString CRemoteListView::GetItemText(int item, unsigned int column)
 			return _T("");
 
 		if (entry.has_time())
-			return entry.time.Format(m_timeFormat);
+			return CTimeFormat::FormatDateTime(entry.time);
 		else
-			return entry.time.Format(m_dateFormat);
+			return CTimeFormat::FormatDate(entry.time);
 	}
 	else if (column == 4)
 		return (*m_pDirectoryListing)[index].permissions;
@@ -3018,7 +3007,12 @@ void CRemoteListView::LinkIsNotDir(const CServerPath& path, const wxString& link
 
 	if (m_pLinkResolveState->remote_path == path && m_pLinkResolveState->link == link)
 	{
-		m_pQueue->QueueFile(false, true, m_pLinkResolveState->local_path, CQueueView::ReplaceInvalidCharacters(link), link, m_pLinkResolveState->remote_path, m_pLinkResolveState->server, -1);
+		wxString localFile = CQueueView::ReplaceInvalidCharacters(link);
+		if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+			localFile = StripVMSRevision(localFile);
+		m_pQueue->QueueFile(false, true,
+			link, (link != localFile) ? localFile : wxString(),
+			m_pLinkResolveState->local_path, m_pLinkResolveState->remote_path, m_pLinkResolveState->server, -1);
 		m_pQueue->QueueFile_Finish(true);
 	}
 
@@ -3036,7 +3030,7 @@ void CRemoteListView::OnMenuGeturl(wxCommandEvent& event)
 		return;
 
 	long item = -1;
-	
+
 	std::list<CDirentry> selected_item_list;
 	while ((item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1)
 	{
