@@ -10,6 +10,7 @@
 #include <wx/clipbrd.h>
 #include "queue.h"
 #include "QueueView.h"
+#include "themeprovider.h"
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -260,6 +261,7 @@ CRemoteTreeView::CRemoteTreeView(wxWindow* parent, wxWindowID id, CState* pState
 
 CRemoteTreeView::~CRemoteTreeView()
 {
+	SetImageList(0);
 	delete m_pImageList;
 }
 
@@ -435,10 +437,11 @@ wxTreeItemId CRemoteTreeView::MakeParent(CServerPath path, bool select)
 wxBitmap CRemoteTreeView::CreateIcon(int index, const wxString& overlay /*=_T("")*/)
 {
 	// Create memory DC
+	wxSize s = CThemeProvider::GetIconSize(iconSizeSmall);
 #ifdef __WXMSW__
-	wxBitmap bmp(16, 16, 32);
+	wxBitmap bmp(s.x, s.y, 32);
 #else
-	wxBitmap bmp(16, 16, 24);
+	wxBitmap bmp(s.x, s.y, 24);
 #endif
 	wxMemoryDC dc;
 	dc.SelectObject(bmp);
@@ -446,7 +449,7 @@ wxBitmap CRemoteTreeView::CreateIcon(int index, const wxString& overlay /*=_T(""
 	// Make sure the background is set correctly
 	dc.SetBrush(wxBrush(GetBackgroundColour()));
 	dc.SetPen(wxPen(GetBackgroundColour()));
-	dc.DrawRectangle(0, 0, 16, 16);
+	dc.DrawRectangle(0, 0, s.x, s.y);
 
 	// Draw item from system image list
 	GetSystemImageList()->Draw(index, dc, 0, 0, wxIMAGELIST_DRAW_TRANSPARENT);
@@ -454,7 +457,7 @@ wxBitmap CRemoteTreeView::CreateIcon(int index, const wxString& overlay /*=_T(""
 	// Load overlay
 	if (overlay != _T(""))
 	{
-		wxImage unknownIcon = wxArtProvider::GetBitmap(overlay, wxART_OTHER, wxSize(16,16)).ConvertToImage();
+		wxImage unknownIcon = wxArtProvider::GetBitmap(overlay, wxART_OTHER, CThemeProvider::GetIconSize(iconSizeSmall)).ConvertToImage();
 
 		// Convert mask into alpha channel
 		if (!unknownIcon.HasAlpha())
@@ -473,7 +476,8 @@ wxBitmap CRemoteTreeView::CreateIcon(int index, const wxString& overlay /*=_T(""
 
 void CRemoteTreeView::CreateImageList()
 {
-	m_pImageList = new wxImageList(16, 16, true, 4);
+	wxSize s = CThemeProvider::GetIconSize(iconSizeSmall);
+	m_pImageList = new wxImageList(s.x, s.y, true, 4);
 
 	// Normal directory
 	int index = GetIconIndex(dir, _T("{78013B9C-3532-4fe1-A418-5CD1955127CC}"), false);
@@ -499,10 +503,10 @@ bool CRemoteTreeView::HasSubdirs(const CDirectoryListing& listing, const CFilter
 	const wxString path = listing.path.GetPath();
 	for (unsigned int i = 0; i < listing.GetCount(); i++)
 	{
-		if (!listing[i].dir)
+		if (!listing[i].is_dir())
 			continue;
 
-		if (filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0))
+		if (filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0, listing[i].has_date() ? &listing[i].time : 0))
 			continue;
 
 		return true;
@@ -520,10 +524,10 @@ void CRemoteTreeView::DisplayItem(wxTreeItemId parent, const CDirectoryListing&
 	CFilterDialog filter;
 	for (unsigned int i = 0; i < listing.GetCount(); i++)
 	{
-		if (!listing[i].dir)
+		if (!listing[i].is_dir())
 			continue;
 
-		if (filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0))
+		if (filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0, listing[i].has_date() ? &listing[i].time : 0))
 			continue;
 
 		const wxString& name = listing[i].name;
@@ -579,10 +583,10 @@ void CRemoteTreeView::RefreshItem(wxTreeItemId parent, const CDirectoryListing&
 	std::list<wxString> dirs;
 	for (unsigned int i = 0; i < listing.GetCount(); i++)
 	{
-		if (!listing[i].dir)
+		if (!listing[i].is_dir())
 			continue;
 
-		if (!filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0))
+		if (!filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0, listing[i].has_date() ? &listing[i].time : 0))
 			dirs.push_back(listing[i].name);
 	}
 
@@ -871,8 +875,6 @@ void CRemoteTreeView::OnBeginDrag(wxTreeEvent& event)
 		return;
 	}
 
-	const wxDataFormat fmt = object.GetReceivedFormat();
-
 #if FZ3_USESHELLEXT
 	if (ext)
 	{
@@ -1037,7 +1039,7 @@ void CRemoteTreeView::OnMenuChmod(wxCommandEvent& event)
 
 		if (pChmodDlg->Recursive())
 			// Start recursion
-			pRecursiveOperation->AddDirectoryToVisit(path, _T(""), _T(""));
+			pRecursiveOperation->AddDirectoryToVisit(path, _T(""), CLocalPath());
 	}
 	else
 	{
@@ -1094,7 +1096,7 @@ void CRemoteTreeView::OnMenuDownload(wxCommandEvent& event)
 	localDir.AddSegment(CQueueView::ReplaceInvalidCharacters(name));
 
 	CRecursiveOperation* pRecursiveOperation = m_pState->GetRecursiveOperationHandler();
-	pRecursiveOperation->AddDirectoryToVisit(path, _T(""), localDir.GetPath());
+	pRecursiveOperation->AddDirectoryToVisit(path, _T(""), localDir);
 
 	CServerPath currentPath;
 	const wxTreeItemId selected = GetSelection();
@@ -1344,7 +1346,7 @@ void CRemoteTreeView::OnChar(wxKeyEvent& event)
 	wxCommandEvent cmdEvt;
 	if (event.GetKeyCode() == WXK_F2)
 		OnMenuRename(cmdEvt);
-	else if (event.GetKeyCode() == WXK_DELETE)
+	else if (event.GetKeyCode() == WXK_DELETE || event.GetKeyCode() == WXK_NUMPAD_DELETE)
 		OnMenuDelete(cmdEvt);
 	else
 		event.Skip();
@@ -1391,7 +1393,7 @@ void CRemoteTreeView::ApplyFilters()
 				if (path.IsEmpty())
 					continue;
 
-				if (filter.FilenameFiltered(GetItemText(child), path.GetPath(), true, -1, false, 0))
+				if (filter.FilenameFiltered(GetItemText(child), path.GetPath(), true, -1, false, 0, 0))
 				{
 					wxTreeItemId sel = GetSelection();
 					while (sel && sel != child)
