@@ -16,11 +16,12 @@ EVT_NAVIGATION_KEY(CQuickconnectBar::OnKeyboardNavigation)
 END_EVENT_TABLE();
 
 CQuickconnectBar::CQuickconnectBar()
+	: m_pHost()
+	, m_pUser()
+	, m_pPass()
+	, m_pPort()
+	, m_pMainFrame()
 {
-	m_pHost = 0;
-	m_pUser = 0;
-	m_pPass = 0;
-	m_pPort = 0;
 }
 
 CQuickconnectBar::~CQuickconnectBar()
@@ -140,16 +141,24 @@ void CQuickconnectBar::OnQuickconnectDropdown(wxCommandEvent& event)
 		pMenu->Append(1, _("Connect bypassing proxy settings"));
 	pMenu->Append(2, _("Clear quickconnect bar"));
 	pMenu->Append(3, _("Clear history"));
-	pMenu->AppendSeparator();
 
 	m_recentServers = CRecentServerList::GetMostRecentServers();
-	unsigned int i = 0;
-	for (std::list<CServer>::const_iterator iter = m_recentServers.begin();
-		iter != m_recentServers.end();
-		iter++, i++)
+	if (!m_recentServers.empty())
 	{
-		pMenu->Append(10 + i, iter->FormatServer());
+		pMenu->AppendSeparator();
+
+		unsigned int i = 0;
+		for (std::list<CServer>::const_iterator iter = m_recentServers.begin();
+			iter != m_recentServers.end();
+			iter++, i++)
+		{
+			wxString name(iter->FormatServer());
+			name.Replace(_T("&"), _T("&&"));
+			pMenu->Append(10 + i, name);
+		}
 	}
+	else
+		pMenu->Enable(3, false);
 
 	XRCCTRL(*this, "ID_QUICKCONNECT_DROPDOWN", wxButton)->PopupMenu(pMenu);
 	delete pMenu;
