@@ -1,7 +1,16 @@
 #ifndef __THEMEPROVIDER_H__
 #define __THEMEPROVIDER_H__
 
-class CThemeProvider : public wxArtProvider
+#include "option_change_event_handler.h"
+
+enum iconSize
+{
+	iconSizeSmall,
+	iconSizeNormal,
+	iconSizeLarge
+};
+
+class CThemeProvider : public wxArtProvider, protected COptionChangeEventHandler
 {
 public:
 	CThemeProvider();
@@ -14,10 +23,16 @@ public:
 	static wxIconBundle GetIconBundle(const wxArtID& id, const wxArtClient& client = wxART_OTHER);
 	static bool ThemeHasSize(const wxString& themePath, const wxString& size);
 
+	static wxSize GetIconSize(enum iconSize size);
+
 protected:
 	static wxString GetThemePath();
+	
+	wxBitmap CreateBitmap(const wxArtID& id, const wxArtClient& /*client*/, const wxSize& size);
 
-	wxBitmap CreateBitmap(const wxArtID& id, const wxArtClient& client, const wxSize& size);
+	std::list<wxString> GetSearchDirs(const wxSize& size);
+
+	virtual void OnOptionChanged(int option);
 
 	wxString m_themePath;
 };
